==> haskell-html-conduit-1.3.2.2-357-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-26htBbKDIvzEK7hYHyNZFB
key:                  html-conduit-1.3.2.2-26htBbKDIvzEK7hYHyNZFB
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  cbb109d380ec807bc90a4a2284389cb3
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-26htBbKDIvzEK7hYHyNZFB
depends:
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j containers-0.6.7
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.2-376-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-36uiJMbfIgCLu2NEgQSZun
key:                  html-conduit-1.3.2.2-36uiJMbfIgCLu2NEgQSZun
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  6a8715df742f976c7c292d7f666f8434
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-36uiJMbfIgCLu2NEgQSZun
depends:
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P containers-0.6.7
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
